==> estateplat-common-1.2.4-20200407.073333-309-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtQqwygl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    前期物业管理表(第九章)
 */
@Table(name = "fcjy_xjspf_mmht_qqwygl")
public class FcjyXjspfMmhtQqwygl implements Serializable {
    @Id
    private String glid;//主键
    private String htid;//合同ID
    private String wymc;//物业名称
    private String zzzh;//资质证号
    private String sffs;//收费方式
    private String wyfjg;//物业费价格（元）
    private String wyfgc;//物业费构成
    private String wyfwqsrq;//物业服务起始日期
    private String wyfwzzrq;//物业服务终止日期

    public String getGlid() {
        return glid;
    }

    public void setGlid(String glid) {
        this.glid = glid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getWymc() {
        return wymc;
    }

    public void setWymc(String wymc) {
        this.wymc = wymc;
    }

    public String getZzzh() {
        return zzzh;
    }

    public void setZzzh(String zzzh) {
        this.zzzh = zzzh;
    }

    public String getSffs() {
        return sffs;
    }

    public void setSffs(String sffs) {
        this.sffs = sffs;
    }

    public String getWyfjg() {
        return wyfjg;
    }

    public void setWyfjg(String wyfjg) {
        this.wyfjg = wyfjg;
    }

    public String getWyfgc() {
        return wyfgc;
    }

    public void setWyfgc(String wyfgc) {
        this.wyfgc = wyfgc;
    }

    public String getWyfwqsrq() {
        return wyfwqsrq;
    }

    public void setWyfwqsrq(String wyfwqsrq) {
        this.wyfwqsrq = wyfwqsrq;
    }

    public String getWyfwzzrq() {
        return wyfwzzrq;
    }

    public void setWyfwzzrq(String wyfwzzrq) {
        this.wyfwzzrq = wyfwzzrq;
    }
}

==> estateplat-common-1.2.4-20800528.082037-169-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtQqwygl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    前期物业管理表(第九章)
 */
@Table(name = "fcjy_xjspf_mmht_qqwygl")
public class FcjyXjspfMmhtQqwygl implements Serializable {
    @Id
    private String glid;//主键
    private String htid;//合同ID
    private String wymc;//物业名称
    private String zzzh;//资质证号
    private String sffs;//收费方式
    private Double wyfjg;//物业费价格（元）
    private String wyfgc;//物业费构成
    private String wyfwqsrq;//物业服务起始日期
    private String wyfwzzrq;//物业服务终止日期

    public String getGlid() {
        return glid;
    }

    public void setGlid(String glid) {
        this.glid = glid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getWymc() {
        return wymc;
    }

    public void setWymc(String wymc) {
        this.wymc = wymc;
    }

    public String getZzzh() {
        return zzzh;
    }

    public void setZzzh(String zzzh) {
        this.zzzh = zzzh;
    }

    public String getSffs() {
        return sffs;
    }

    public void setSffs(String sffs) {
        this.sffs = sffs;
    }

    public Double getWyfjg() {
        return wyfjg;
    }

    public void setWyfjg(Double wyfjg) {
        this.wyfjg = wyfjg;
    }

    public String getWyfgc() {
        return wyfgc;
    }

    public void setWyfgc(String wyfgc) {
        this.wyfgc = wyfgc;
    }

    public String getWyfwqsrq() {
        return wyfwqsrq;
    }

    public void setWyfwqsrq(String wyfwqsrq) {
        this.wyfwqsrq = wyfwqsrq;
    }

    public String getWyfwzzrq() {
        return wyfwzzrq;
    }

    public void setWyfwzzrq(String wyfwzzrq) {
        this.wyfwzzrq = wyfwzzrq;
    }
}
